@@ -20,8 +20,6 @@ class TB6612FNGCodes:
     """
     Operational codes used to send commands to the driver module via I2C interface.
     """
-    def __init__(self):
-        pass
 
     # module address
     GMD_I2C_ADDRESS = 0x14
