@@ -21,8 +21,6 @@ class TB6612FNGMotors:
     The motor selection contains two values: MOTOR_CHA and MOTOR_CHB,
     used to choose which motor to operate via the motor driver.
     """
-    def __init__(self):
-        pass
 
     MOTOR_CHA = 0
-    MOTOR_CHB = 1
+    MOTOR_CH = 1
