@@ -18,10 +18,8 @@
 
 class TB6612FNGStepper:
     """
-    A class for stepper motor commands enum.
+    An enum for stepper motor commands enum.
     """
-    def __init__(self):
-        pass
 
     FULL_STEP = 0
     WAVE_DRIVE = 1
